@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::PluginBundle::NGLENN;
 # ABSTRACT: Dist::Zilla plugin configuration for me
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 # Dependencies
 use Moose 0.99;
@@ -29,6 +29,7 @@ use Dist::Zilla::Plugin::Git::NextVersion             ();
 # use Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch ();
 use Dist::Zilla::Plugin::GithubMeta 0.36       ();
 use Dist::Zilla::Plugin::TravisYML ();
+use Dist::Zilla::Plugin::TravisCI::StatusBadge;
 use Dist::Zilla::Plugin::InsertCopyright 0.001 ();
 use Dist::Zilla::Plugin::MetaNoIndex ();
 use Dist::Zilla::Plugin::MetaProvides::Package 1.14 (); # hides private packages
@@ -255,6 +256,7 @@ sub configure {
 
         # generated distribution files
         'ReadmeFromPod', # in build dir
+        'TravisCI::StatusBadge', # in readme file
         'License',       # core
 
         # Travis config file
@@ -448,7 +450,7 @@ __PACKAGE__->meta->make_immutable;
 #
 # This file is part of Dist-Zilla-PluginBundle-NGLENN
 #
-# This software is Copyright (c) 2014 by Nathan Glenn.
+# This software is Copyright (c) 2015 by Nathan Glenn.
 #
 # This is free software, licensed under:
 #
@@ -467,7 +469,7 @@ Dist::Zilla::PluginBundle::NGLENN - Dist::Zilla plugin configuration for me
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -487,9 +489,8 @@ following dist.ini:
 
   ; choose files to include
   [Git::GatherDir]         ; everything from git ls-files
-  exclude_filename = README.pod   ; skip this generated file
   exclude_filename = README.mkdn  ; skip this generated file
-  exclude_filename = META.json    ; skip this generated file
+  exclude_filename = Makefile.PL  ; skip this generated file
   exclude_filename = cpanfile     ; skip this generated file
 
   [PruneCruft]        ; default stuff to skip
@@ -813,7 +814,7 @@ Sergey Romanov <complefor@rambler.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Nathan Glenn.
+This software is Copyright (c) 2015 by Nathan Glenn.
 
 This is free software, licensed under:
 
